/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration;

import org.springframework.core.task.TaskExecutor;

import com.google.protobuf.ByteString;

import de.ozgcloud.apilib.file.OzgCloudFileId;
import de.ozgcloud.collaboration.common.callcontext.CollaborationManagerCallContextGrpcServerInterceptor;
import de.ozgcloud.collaboration.common.file.CollaborationFileService;
import de.ozgcloud.collaboration.vorgang.CollaborationVorgangMapper;
import de.ozgcloud.collaboration.vorgang.Vorgang;
import de.ozgcloud.collaboration.vorgang.VorgangService;
import de.ozgcloud.common.binaryfile.GrpcBinaryFileServerDownloader;
import io.grpc.stub.CallStreamObserver;
import io.grpc.stub.StreamObserver;
import lombok.RequiredArgsConstructor;
import net.devh.boot.grpc.server.service.GrpcService;

@GrpcService(interceptors = { CollaborationManagerCallContextGrpcServerInterceptor.class })
@RequiredArgsConstructor
public class CollaborationGrpcService extends CollaborationServiceGrpc.CollaborationServiceImplBase {

	private final CollaborationVorgangMapper vorgangMapper;

	private final CollaborationFileService fileService;
	private final VorgangService vorgangService;

	private final TaskExecutor taskExecutor;

	@Override
	public void findVorgang(GrpcFindVorgangRequest request, StreamObserver<GrpcFindVorgangResponse> responseObserver) {
		var vorgang = vorgangService.getVorgang(request.getVorgangId());

		responseObserver.onNext(buildFindVorgangResponse(vorgang));
		responseObserver.onCompleted();
	}

	GrpcFindVorgangResponse buildFindVorgangResponse(Vorgang vorgang) {
		return GrpcFindVorgangResponse.newBuilder()
				.setVorgang(vorgangMapper.toGrpc(vorgang))
				.build();
	}

	@Override
	public void getFileContent(GrpcGetFileContentRequest request, StreamObserver<GrpcGetFileContentResponse> responseObserver) {
		buildDownloader(request.getId(), responseObserver).start();
	}

	GrpcBinaryFileServerDownloader<GrpcGetFileContentResponse> buildDownloader(String fileId,
			StreamObserver<GrpcGetFileContentResponse> responseObserver) {
		return GrpcBinaryFileServerDownloader.<GrpcGetFileContentResponse>builder()
				.callObserver((CallStreamObserver<GrpcGetFileContentResponse>) responseObserver)
				.downloadConsumer(outputStream -> fileService.download(OzgCloudFileId.from(fileId), outputStream))
				.chunkBuilder(this::buildChunkResponse)
				.taskExecutor(taskExecutor)
				.build();
	}

	GrpcGetFileContentResponse buildChunkResponse(ByteString bytes) {
		return GrpcGetFileContentResponse.newBuilder().setFileContent(bytes).build();
	}
}