/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration;

import jakarta.validation.Valid;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;

import de.ozgcloud.collaboration.fachstelle.Fachstelle;
import de.ozgcloud.collaboration.request.CollaborationRequestId;
import lombok.Builder;
import lombok.Getter;

@Builder(toBuilder = true)
@Getter
public class CollaborationRequest {

	public static final String PROPERTY_ID = "id";
	public static final String PROPERTY_COMMAND_ID = "commandId";
	public static final String PROPERTY_VORGANG_ID = "vorgangId";
	public static final String PROPERTY_COLLABORATION_VORGANG_ID = "collaborationVorgangId";
	public static final String PROPERTY_COLLABORATION_LEVEL = "collaborationLevel";

	public static final String PROPERTY_CREATED_BY = "createdBy";

	public static final String PROPERTY_TITEL = "titel";
	public static final String PROPERTY_BESCHREIBUNG = "beschreibung";
	public static final String PROPERTY_ZUSTAENDIGE_STELLE = "zustaendigeStelle";

	private CollaborationRequestId id;

	private String commandId;
	private String vorgangId;
	private String collaborationVorgangId;

	private int collaborationLevel;

	private String createdBy;

	@NotBlank
	private String titel;
	@NotBlank
	private String beschreibung;
	@Valid
	@NotNull
	private Fachstelle zustaendigeStelle;
}
