/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration;

import java.net.URLEncoder;
import java.nio.charset.StandardCharsets;

import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.stereotype.Component;

@Component
@ConditionalOnProperty(prefix = FachstelleProperties.PREFIX, name = { "host" })
class FachstelleVorgangUrlProvider {

	static final String URL_PATH_RESOURCES = "/resources?"; // NOSONAR
	static final String QUERY_PARAM_URI = "uri=";
	static final String URI_PATH_TEMPLATE = "%s/vorgangs/";

	private final String vorgangUrlPrefix;

	FachstelleVorgangUrlProvider(FachstelleProperties fachstelleProperties,
			@Qualifier(CollaborationManagerConfiguration.VORGANG_MANAGER_PROPERTIES_NAME) VorgangManagerProperties vorgangManagerProperties) {
		this.vorgangUrlPrefix = getFachstelleHost(fachstelleProperties) + URL_PATH_RESOURCES + buildUriQuery(vorgangManagerProperties);
	}

	String getFachstelleHost(FachstelleProperties fachstelleProperties) {
		return fachstelleProperties.getHost().startsWith("http") ? fachstelleProperties.getHost() : "https://" + fachstelleProperties.getHost();
	}

	private String buildUriQuery(VorgangManagerProperties vorgangManagerProperties) {
		var uriPath = URI_PATH_TEMPLATE.formatted(getServiceName(vorgangManagerProperties));
		return QUERY_PARAM_URI + URLEncoder.encode(uriPath, StandardCharsets.UTF_8);
	}

	String getServiceName(VorgangManagerProperties vorgangManagerProperties) {
		return getDomainWithoutPort(getDomainWithoutProtocol(vorgangManagerProperties.getServiceAddress()));
	}

	private String getDomainWithoutProtocol(String serviceAddress) {
		var protocolEnd = serviceAddress.lastIndexOf("/");
		return protocolEnd == -1 ? serviceAddress : serviceAddress.substring(protocolEnd + 1);
	}

	private String getDomainWithoutPort(String serviceAddress) {
		var portStart = serviceAddress.lastIndexOf(":");
		return portStart == -1 ? serviceAddress : serviceAddress.substring(0, portStart);
	}

	public String getUrl(String vorgangId) {
		return vorgangUrlPrefix + vorgangId;
	}
}
