/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration.common.callcontext;

import java.util.Optional;

import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Component;

import de.ozgcloud.apilib.common.callcontext.CallContext;
import de.ozgcloud.apilib.common.callcontext.OzgCloudCallContextProvider;
import de.ozgcloud.apilib.user.OzgCloudUserId;
import de.ozgcloud.collaboration.CollaborationManagerConfiguration;
import lombok.RequiredArgsConstructor;

@Component(CollaborationManagerConfiguration.CALL_CONTEXT_PROVIDER_NAME)
@RequiredArgsConstructor
public class CollaborationManagerCallContextProvider implements OzgCloudCallContextProvider {

	@Qualifier(CollaborationManagerConfiguration.CURRENT_USER_SERVICE_NAME)
	private final CurrentUserService currentUserService;

	@Override
	public CallContext provideContext() {
		var callContextBuilder = CallContext.builder().clientName(CollaborationManagerCallContextGrpcClientInterceptor.COLLABORATION_MANAGER_CLIENT_NAME);
		getUserId().ifPresent(callContextBuilder::userId);
		return callContextBuilder.build();
	}

	Optional<OzgCloudUserId> getUserId() {
		return currentUserService.getUser().getUserId().map(OzgCloudUserId::from);
	}
}
