/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration.common.freemarker;

import java.io.IOException;
import java.io.StringWriter;

import org.springframework.stereotype.Component;

import de.ozgcloud.collaboration.CollaborationManagerConfiguration;
import de.ozgcloud.common.errorhandling.TechnicalException;
import freemarker.template.Configuration;
import freemarker.template.Template;
import freemarker.template.TemplateException;
import lombok.RequiredArgsConstructor;

@Component(CollaborationManagerConfiguration.TEMPLATE_HANDLER_NAME)
@RequiredArgsConstructor
public class TemplateHandler {

	private final Configuration freemarkerConfig;

	public String fillTemplate(String templateName, Object dataModel) {
		try {
			var template = getTemplate(templateName);
			var stringWriter = new StringWriter();
			template.process(dataModel, stringWriter);
			return stringWriter.toString();

		} catch (IOException | TemplateException e) {
			throw new TechnicalException("Error filling template", e);
		}
	}

	private Template getTemplate(String templateName) {
		try {
			return freemarkerConfig.getTemplate(templateName);
		} catch (IOException e) {
			throw new TechnicalException("Error loading mail template", e);
		}
	}
}
