/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration.common.vorgang.attached_item;

import java.util.stream.Stream;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

import de.ozgcloud.collaboration.CollaborationManagerConfiguration;
import de.ozgcloud.vorgang.vorgangAttachedItem.GrpcFindVorgangAttachedItemRequest;
import de.ozgcloud.vorgang.vorgangAttachedItem.GrpcVorgangAttachedItemRequest;
import de.ozgcloud.vorgang.vorgangAttachedItem.VorgangAttachedItemServiceGrpc.VorgangAttachedItemServiceBlockingStub;
import io.grpc.ClientInterceptor;
import net.devh.boot.grpc.client.inject.GrpcClient;

@Service(CollaborationManagerConfiguration.VORGANG_ATTACHED_ITEM_REMOTE_SERVICE_NAME)
class VorgangAttachedItemRemoteService {

	@GrpcClient(CollaborationManagerConfiguration.GRPC_VORGANG_MANAGER_NAME)
	private VorgangAttachedItemServiceBlockingStub stub;
	@Autowired
	private CollaborationManagerVorgangAttachedItemMapper mapper;

	@Qualifier(CollaborationManagerConfiguration.CALL_CONTEXT_INTERCEPTOR_NAME)
	@Autowired
	private ClientInterceptor interceptor;

	public VorgangAttachedItem getById(String id) {
		var item = getStub().getById(GrpcVorgangAttachedItemRequest.newBuilder().setId(id).build());

		return mapper.fromGrpc(item.getVorgangAttachedItem());
	}

	public Stream<VorgangAttachedItem> findByVorgangId(String vorgangId, String itemName) {
		var items = getStub().find(buildFindRequest(vorgangId, itemName));

		return items.getVorgangAttachedItemsList().stream().map(mapper::fromGrpc);
	}

	private GrpcFindVorgangAttachedItemRequest buildFindRequest(String vorgangId, String itemName) {
		return GrpcFindVorgangAttachedItemRequest.newBuilder()
				.setVorgangId(vorgangId)
				.setItemName(itemName)
				.build();
	}

	VorgangAttachedItemServiceBlockingStub getStub() {
		return stub.withInterceptors(interceptor);
	}
}