/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration.fachstelle;

import java.util.Map;

import org.apache.commons.collections.MapUtils;
import org.mapstruct.AnnotateWith;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.NullValueCheckStrategy;
import org.mapstruct.NullValuePropertyMappingStrategy;
import org.mapstruct.ReportingPolicy;
import org.springframework.stereotype.Component;

import de.ozgcloud.collaboration.CollaborationManagerConfiguration;
import de.ozgcloud.collaboration.fachstelle.Fachstelle.FachstelleType;
import de.ozgcloud.zufi.grpc.fachstelle.GrpcFachstelle;
import de.ozgcloud.zufi.grpc.organisationseinheit.GrpcOrganisationsEinheit;

@Mapper(unmappedTargetPolicy = ReportingPolicy.WARN, nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS, nullValuePropertyMappingStrategy = NullValuePropertyMappingStrategy.IGNORE, //
		imports = FachstelleType.class)
@AnnotateWith(value = Component.class, elements = @AnnotateWith.Element(strings = CollaborationManagerConfiguration.FACHSTELLE_MAPPER_NAME))
public interface FachstelleMapper {

	@Mapping(target = "technicalId", source = "id")
	@Mapping(target = "subjectId", source = "mukId")
	@Mapping(target = "type", expression = "java(FachstelleType.EXTERNE_FACHSTELLE)")
	Fachstelle fromExterneFachstelle(GrpcFachstelle externeFachstelle);

	@Mapping(target = "technicalId", source = "id")
	@Mapping(target = "subjectId", source = "xzufiId.id")
	@Mapping(target = "type", expression = "java(FachstelleType.ORGANISATION_EINHEIT)")
	Fachstelle fromOrganisationEinheit(GrpcOrganisationsEinheit organisationsEinheit);

	default Map<String, Object> toMap(Fachstelle fachstelle) {
		return Map.of(
				Fachstelle.PROPERTY_TECHNICAL_ID, fachstelle.getTechnicalId(),
				Fachstelle.PROPERTY_SUBJECT_ID, fachstelle.getSubjectId(),
				Fachstelle.PROPERTY_TYPE, fachstelle.getType().name());
	}

	default Fachstelle fromMap(Map<?, ?> fachstelleMap) {
		return Fachstelle.builder()
				.technicalId(MapUtils.getString(fachstelleMap, Fachstelle.PROPERTY_TECHNICAL_ID))
				.subjectId(MapUtils.getString(fachstelleMap, Fachstelle.PROPERTY_SUBJECT_ID))
				.type(FachstelleType.valueOf(MapUtils.getString(fachstelleMap, Fachstelle.PROPERTY_TYPE)))
				.build();
	}
}
