/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration.fachstelle;

import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

import de.ozgcloud.collaboration.CollaborationManagerConfiguration;
import de.ozgcloud.collaboration.common.callcontext.CollaborationManagerCallContextGrpcClientInterceptor;
import de.ozgcloud.zufi.grpc.fachstelle.FachstelleServiceGrpc.FachstelleServiceBlockingStub;
import de.ozgcloud.zufi.grpc.fachstelle.GrpcFachstelleGetRequest;
import de.ozgcloud.zufi.grpc.organisationseinheit.GrpcOrganisationsEinheitGetRequest;
import de.ozgcloud.zufi.grpc.organisationseinheit.OrganisationsEinheitServiceGrpc.OrganisationsEinheitServiceBlockingStub;
import lombok.RequiredArgsConstructor;
import net.devh.boot.grpc.client.inject.GrpcClient;

@Service
@RequiredArgsConstructor
class FachstelleRemoteService {

	@GrpcClient(CollaborationManagerConfiguration.GRPC_ZUFI_MANAGER_NAME)
	private final FachstelleServiceBlockingStub fachstelleServiceBlockingStub;
	@GrpcClient(CollaborationManagerConfiguration.GRPC_ZUFI_MANAGER_NAME)
	private final OrganisationsEinheitServiceBlockingStub organisationsEinheitServiceBlockingStub;
	@Qualifier(CollaborationManagerConfiguration.FACHSTELLE_MAPPER_NAME) // NOSONAR
	private final FachstelleMapper fachstelleMapper;
	@Qualifier(CollaborationManagerConfiguration.CALL_CONTEXT_INTERCEPTOR_NAME) // NOSONAR
	private final CollaborationManagerCallContextGrpcClientInterceptor callContextInterceptor;

	public Fachstelle getExterneFachstelle(String id) {
		var externeFachstelle = getFachstelleServiceBlockingStub().getById(GrpcFachstelleGetRequest.newBuilder().setId(id).build()).getFachstelle();
		return fachstelleMapper.fromExterneFachstelle(externeFachstelle);
	}

	FachstelleServiceBlockingStub getFachstelleServiceBlockingStub() {
		return fachstelleServiceBlockingStub.withInterceptors(callContextInterceptor);
	}

	public Fachstelle getOrganisationEinheit(String id) {
		var organisationEinheit = getOrganisationsEinheitServiceBlockingStub()
				.getById(GrpcOrganisationsEinheitGetRequest.newBuilder().setId(id).build())
				.getOrganisationsEinheit();
		return fachstelleMapper.fromOrganisationEinheit(organisationEinheit);
	}

	public OrganisationsEinheitServiceBlockingStub getOrganisationsEinheitServiceBlockingStub() {
		return organisationsEinheitServiceBlockingStub.withInterceptors(callContextInterceptor);
	}
}
