/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration.request;

import java.util.stream.Stream;

import org.springframework.beans.factory.annotation.Qualifier;

import de.ozgcloud.collaboration.CollaborationManagerConfiguration;
import de.ozgcloud.collaboration.CollaborationRequest;
import de.ozgcloud.collaboration.CollaborationRequestMapper;
import de.ozgcloud.collaboration.common.callcontext.CollaborationManagerCallContextGrpcServerInterceptor;
import de.ozgcloud.collaboration.request.CollaborationRequestServiceGrpc.CollaborationRequestServiceImplBase;
import io.grpc.stub.StreamObserver;
import lombok.RequiredArgsConstructor;
import net.devh.boot.grpc.server.service.GrpcService;

@GrpcService(interceptors = { CollaborationManagerCallContextGrpcServerInterceptor.class })
@RequiredArgsConstructor
public class CollaborationRequestGrpcService extends CollaborationRequestServiceImplBase {

	private final CollaborationRequestService service;
	@Qualifier(CollaborationManagerConfiguration.COLLABORATION_REQUEST_MAPPER_NAME) // NOSONAR
	private final CollaborationRequestMapper mapper;

	@Override
	public void getRequest(GrpcGetRequestRequest request, StreamObserver<GrpcGetRequestResponse> responseObserver) {
		var collaborationRequest = service.getById(request.getId());

		responseObserver.onNext(buildGrpcGetRequestResponse(collaborationRequest));
		responseObserver.onCompleted();
	}

	private GrpcGetRequestResponse buildGrpcGetRequestResponse(CollaborationRequest collaborationRequest) {
		return GrpcGetRequestResponse.newBuilder().setRequest(mapper.toGrpcCollaborationRequest(collaborationRequest)).build();
	}

	@Override
	public void findRequests(GrpcFindRequestsRequest request, StreamObserver<GrpcFindRequestsResponse> responseObserver) {
		var requests = service.findByVorgangId(request.getVorgangId());

		responseObserver.onNext(buildGrpcFindRequestsResponse(requests));
		responseObserver.onCompleted();
	}

	private GrpcFindRequestsResponse buildGrpcFindRequestsResponse(Stream<CollaborationRequest> requests) {
		return GrpcFindRequestsResponse.newBuilder().addAllRequests(requests.map(mapper::toGrpcCollaborationRequest).toList()).build();
	}
}