/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration.request;

import java.util.stream.Stream;

import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

import de.ozgcloud.collaboration.CollaborationManagerConfiguration;
import de.ozgcloud.collaboration.CollaborationRequest;
import de.ozgcloud.collaboration.CollaborationRequestMapper;
import de.ozgcloud.collaboration.common.vorgang.attached_item.VorgangAttachedItemService;
import lombok.RequiredArgsConstructor;

@RequiredArgsConstructor
@Service
class CollaborationRequestService {

	static final String VORGANG_ATTACHED_ITEM_NAME = "CollaborationRequest";

	@Qualifier(CollaborationManagerConfiguration.VORGANG_ATTACHED_ITEM_SERVICE_NAME)
	private final VorgangAttachedItemService vorgangAttachedItemService;
	@Qualifier(CollaborationManagerConfiguration.COLLABORATION_REQUEST_MAPPER_NAME) // NOSONAR
	private final CollaborationRequestMapper mapper;

	public CollaborationRequest getById(String id) {
		var item = vorgangAttachedItemService.getById(id);
		return mapper.mapFromVorgangAttachedItem(item);
	}

	public Stream<CollaborationRequest> findByVorgangId(String vorgangId) {
		var items = vorgangAttachedItemService.findByVorgangId(vorgangId, VORGANG_ATTACHED_ITEM_NAME);
		return items.map(mapper::mapFromVorgangAttachedItem);
	}
}