/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration.vorgang;

import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.NullValueCheckStrategy;
import org.mapstruct.ReportingPolicy;

import de.ozgcloud.apilib.vorgang.OzgCloudAntragsteller;
import de.ozgcloud.collaboration.GrpcAntragsteller;

@Mapper(uses = { CollaborationFormDataMapper.class },
		nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS,
		unmappedTargetPolicy = ReportingPolicy.WARN)
interface CollaborationAntragstellerMapper {

	Antragsteller fromOzgCloudAntragsteller(OzgCloudAntragsteller antragsteller);

	@Mapping(target = "otherDataOrBuilder", ignore = true)
	@Mapping(target = "defaultInstanceForType", ignore = true)
	@Mapping(target = "mergeFrom", ignore = true)
	@Mapping(target = "clearField", ignore = true)
	@Mapping(target = "clearOneof", ignore = true)
	@Mapping(target = "mergeOtherData", ignore = true)
	@Mapping(target = "mergeUnknownFields", ignore = true)
	@Mapping(target = "anredeBytes", ignore = true)
	@Mapping(target = "emailBytes", ignore = true)
	@Mapping(target = "firmaNameBytes", ignore = true)
	@Mapping(target = "geburtsdatumBytes", ignore = true)
	@Mapping(target = "geburtsnameBytes", ignore = true)
	@Mapping(target = "geburtsortBytes", ignore = true)
	@Mapping(target = "hausnummerBytes", ignore = true)
	@Mapping(target = "nachnameBytes", ignore = true)
	@Mapping(target = "ortBytes", ignore = true)
	@Mapping(target = "plzBytes", ignore = true)
	@Mapping(target = "strasseBytes", ignore = true)
	@Mapping(target = "telefonBytes", ignore = true)
	@Mapping(target = "unknownFields", ignore = true)
	@Mapping(target = "vornameBytes", ignore = true)
	@Mapping(target = "allFields", ignore = true)
	GrpcAntragsteller toGrpc(Antragsteller antragsteller);
}