/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration.vorgang;

import org.mapstruct.CollectionMappingStrategy;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.NullValueCheckStrategy;
import org.mapstruct.NullValueMappingStrategy;
import org.mapstruct.NullValuePropertyMappingStrategy;

import de.ozgcloud.apilib.vorgang.OzgCloudEingang;
import de.ozgcloud.collaboration.GrpcEingang;
import de.ozgcloud.collaboration.common.file.CollaborationFileGroupMapper;
import de.ozgcloud.collaboration.common.file.CollaborationFileMapper;

@Mapper(uses = { CollaborationAntragstellerMapper.class, CollaborationFileGroupMapper.class, CollaborationFileMapper.class,
		CollaborationFormDataMapper.class }, //
		collectionMappingStrategy = CollectionMappingStrategy.ADDER_PREFERRED, ////
		nullValuePropertyMappingStrategy = NullValuePropertyMappingStrategy.SET_TO_NULL, //
		nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS, //
		nullValueMappingStrategy = NullValueMappingStrategy.RETURN_DEFAULT)
interface CollaborationEingangMapper {

	@Mapping(target = "attachment", ignore = true)
	@Mapping(target = "representation", ignore = true)
	@Mapping(target = "formDataEntrys", source = "formDataEntrys")
	Eingang fromOzgCloudEingang(OzgCloudEingang eingang);

	@Mapping(target = "formDataOrBuilder", ignore = true)
	@Mapping(target = "defaultInstanceForType", ignore = true)
	@Mapping(target = "antragstellerOrBuilder", ignore = true)
	@Mapping(target = "mergeFrom", ignore = true)
	@Mapping(target = "clearField", ignore = true)
	@Mapping(target = "clearOneof", ignore = true)
	@Mapping(target = "mergeAntragsteller", ignore = true)
	@Mapping(target = "mergeFormData", ignore = true)
	@Mapping(target = "mergeUnknownFields", ignore = true)
	@Mapping(target = "removeAttachments", ignore = true)
	@Mapping(target = "removeRepresentations", ignore = true)
	@Mapping(target = "unknownFields", ignore = true)
	@Mapping(target = "allFields", ignore = true)
	@Mapping(target = "attachmentsBuilderList", ignore = true)
	@Mapping(target = "attachmentsOrBuilderList", ignore = true)
	@Mapping(target = "representationsBuilderList", ignore = true)
	@Mapping(target = "representationsOrBuilderList", ignore = true)

	@Mapping(target = "attachmentsList", source = "attachments")
	@Mapping(target = "representationsList", source = "representations")
	@Mapping(target = "formData", source = "formDataEntrys")
	GrpcEingang toGrpc(Eingang eingang);
}