/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration.vorgang;

import java.util.Collection;
import java.util.Collections;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

import org.mapstruct.CollectionMappingStrategy;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.NullValueCheckStrategy;
import org.mapstruct.NullValuePropertyMappingStrategy;
import org.mapstruct.ReportingPolicy;

import de.ozgcloud.apilib.vorgang.OzgCloudPostfachAddressIdentifier;
import de.ozgcloud.apilib.vorgang.OzgCloudServiceKonto;
import de.ozgcloud.apilib.vorgang.OzgCloudTrustLevel;
import de.ozgcloud.common.datatype.StringBasedValue;
import de.ozgcloud.vorgang.common.grpc.GrpcObjectMapper;
import de.ozgcloud.vorgang.vorgang.GrpcServiceKonto;

@Mapper(unmappedTargetPolicy = ReportingPolicy.WARN,
		unmappedSourcePolicy = ReportingPolicy.WARN,
		nullValuePropertyMappingStrategy = NullValuePropertyMappingStrategy.IGNORE,
		nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS,
		collectionMappingStrategy = CollectionMappingStrategy.ADDER_PREFERRED,
		uses = GrpcObjectMapper.class)
public interface CollaborationServiceKontoMapper {

	@Mapping(target = "addresses", ignore = true)
	@Mapping(target = "address.identifier", source = "address.identifiers")
	ServiceKonto fromServiceKonto(OzgCloudServiceKonto serviceKonto);

	default TrustLevel fromTrustLevel(OzgCloudTrustLevel value) {
		return TrustLevel.from(value);
	}

	default Map<String, Object> fromPostfachAddressIdentifier(Collection<OzgCloudPostfachAddressIdentifier> postfachAddressIdentifier) {
		if (Objects.isNull(postfachAddressIdentifier)) {
			return Collections.emptyMap();
		}
		return postfachAddressIdentifier.stream()
				.collect(Collectors.toMap(OzgCloudPostfachAddressIdentifier::getName, OzgCloudPostfachAddressIdentifier::getValue));
	}

	default String fromStringBasedValue(StringBasedValue value) {
		return value.toString();
	}

	@Mapping(target = "unknownFields", ignore = true)
	@Mapping(target = "typeBytes", ignore = true)
	@Mapping(target = "trustLevelBytes", ignore = true)
	@Mapping(target = "removePostfachAddresses", ignore = true)
	@Mapping(target = "postfachAddressesOrBuilderList", ignore = true)
	@Mapping(target = "postfachAddressesBuilderList", ignore = true)
	@Mapping(target = "mergeUnknownFields", ignore = true)
	@Mapping(target = "mergeFrom", ignore = true)
	@Mapping(target = "defaultInstanceForType", ignore = true)
	@Mapping(target = "clearOneof", ignore = true)
	@Mapping(target = "clearField", ignore = true)
	@Mapping(target = "allFields", ignore = true)

	@Mapping(target = "postfachAddressesList", source = "addresses")
	GrpcServiceKonto toServiceKonto(ServiceKonto serviceKonto);

	default String toString(TrustLevel trustLevel) {
		return trustLevel.getValue();
	}
}