/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration.vorgang;

import java.util.List;

import org.apache.commons.collections.CollectionUtils;
import org.mapstruct.CollectionMappingStrategy;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.NullValueCheckStrategy;
import org.mapstruct.NullValuePropertyMappingStrategy;
import org.mapstruct.ReportingPolicy;

import de.ozgcloud.apilib.vorgang.OzgCloudVorgang;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangId;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangIdMapper;
import de.ozgcloud.collaboration.GrpcVorgang;

@Mapper(uses = { OzgCloudVorgangIdMapper.class, CollaborationEingangMapper.class, CollaborationServiceKontoMapper.class }, //
		unmappedTargetPolicy = ReportingPolicy.WARN, //
		collectionMappingStrategy = CollectionMappingStrategy.ADDER_PREFERRED, //
		nullValuePropertyMappingStrategy = NullValuePropertyMappingStrategy.IGNORE, //
		nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS)
public interface CollaborationVorgangMapper {

	@Mapping(target = "eingang", ignore = true)
	@Mapping(target = "header.serviceKonto", source = "header.serviceKonto")
	Vorgang fromOzgCloudVorgang(OzgCloudVorgang vorgang);

	@Mapping(target = "headerOrBuilder", ignore = true)
	@Mapping(target = "eingangOrBuilder", ignore = true)
	@Mapping(target = "defaultInstanceForType", ignore = true)
	@Mapping(target = "mergeFrom", ignore = true)
	@Mapping(target = "clearField", ignore = true)
	@Mapping(target = "clearOneof", ignore = true)
	@Mapping(target = "mergeEingang", ignore = true)
	@Mapping(target = "mergeHeader", ignore = true)
	@Mapping(target = "mergeUnknownFields", ignore = true)
	@Mapping(target = "idBytes", ignore = true)
	@Mapping(target = "unknownFields", ignore = true)
	@Mapping(target = "vorgangNameBytes", ignore = true)
	@Mapping(target = "vorgangNummerBytes", ignore = true)
	@Mapping(target = "allFields", ignore = true)

	@Mapping(target = "eingang", source = "eingangs")
	GrpcVorgang toGrpc(Vorgang vorgang);

	default String toString(OzgCloudVorgangId id) {
		return id.toString();
	}

	default Eingang mapListToGrpcEingang(List<Eingang> eingaenge) {
		if (CollectionUtils.isEmpty(eingaenge)) {
			return null;
		}
		return eingaenge.get(0);
	}
}