/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration.vorgang;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

import de.ozgcloud.apilib.vorgang.OzgCloudVorgangId;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangService;
import de.ozgcloud.collaboration.CollaborationManagerConfiguration;
import de.ozgcloud.collaboration.CollaborationRequest;
import de.ozgcloud.collaboration.common.callcontext.CollaborationManagerCallContextGrpcClientInterceptor;
import de.ozgcloud.collaboration.CollaborationRequestMapper;
import de.ozgcloud.vorgang.vorgang.GrpcCreateCollaborationVorgangRequest;
import de.ozgcloud.vorgang.vorgang.VorgangServiceGrpc.VorgangServiceBlockingStub;
import net.devh.boot.grpc.client.inject.GrpcClient;

@Service(CollaborationManagerConfiguration.VORGANG_REMOTE_SERVICE_NAME)
class VorgangRemoteService {

	@GrpcClient(CollaborationManagerConfiguration.GRPC_VORGANG_MANAGER_NAME)
	private VorgangServiceBlockingStub vorgangServiceBlockingStub;

	@Autowired
	@Qualifier(CollaborationManagerConfiguration.VORGANG_OZGCLOUD_SERVICE_NAME)
	private OzgCloudVorgangService ozgCloudVorgangService;
	@Autowired
	@Qualifier(CollaborationManagerConfiguration.COLLABORATION_REQUEST_MAPPER_NAME) // NOSONAR
	private CollaborationRequestMapper collaborationRequestMapper;

	@Autowired
	private CollaborationVorgangMapper mapper;

	@Autowired
	@Qualifier(CollaborationManagerConfiguration.CALL_CONTEXT_INTERCEPTOR_NAME)
	private CollaborationManagerCallContextGrpcClientInterceptor callContextInterceptor;

	public String createCollaborationVorgang(CollaborationRequest request) {
		return getServiceStub().createCollaborationVorgang(buildCreateCollaborationVorgangRequest(request)).getVorgangId();
	}

	GrpcCreateCollaborationVorgangRequest buildCreateCollaborationVorgangRequest(CollaborationRequest request) {
		return GrpcCreateCollaborationVorgangRequest.newBuilder()
				.setRequestData(collaborationRequestMapper.toGrpcCreateCollaborationRequestData(request))
				.build();
	}

	VorgangServiceBlockingStub getServiceStub() {
		return vorgangServiceBlockingStub.withInterceptors(callContextInterceptor);
	}

	public Vorgang getVorgang(OzgCloudVorgangId vorgangId) {
		return mapper.fromOzgCloudVorgang(ozgCloudVorgangService.getById(vorgangId));
	}
}
