/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration;

import java.util.Map;
import java.util.UUID;

import com.thedeanda.lorem.LoremIpsum;

import de.ozgcloud.collaboration.CollaborationRequest.CollaborationRequestBuilder;
import de.ozgcloud.collaboration.fachstelle.Fachstelle;
import de.ozgcloud.collaboration.fachstelle.FachstelleTestFactory;
import de.ozgcloud.collaboration.request.CollaborationRequestId;
import de.ozgcloud.collaboration.vorgang.VorgangTestFactory;
import de.ozgcloud.command.CommandTestFactory;

public class CollaborationRequestTestFactory {

	public static final String ID_STR = UUID.randomUUID().toString();
	public static final CollaborationRequestId ID = CollaborationRequestId.from(ID_STR);

	public static final String TITEL = LoremIpsum.getInstance().getWords(5);
	public static final String BESCHREIBUNG = LoremIpsum.getInstance().getWords(10);
	public static final String COLLABORATION_VORGANG_ID = UUID.randomUUID().toString();
	public static final int COLLABORATION_LEVEL = 1;
	public static final Fachstelle ZUSTAENDIGE_STELLE = FachstelleTestFactory.create();
	public static final Map<String, Object> FACHSTELLE_MAP = FachstelleTestFactory.createAsMap();

	public static CollaborationRequest create() {
		return createBuilder().build();
	}

	public static CollaborationRequestBuilder createBuilder() {
		return CollaborationRequest.builder()
				.id(ID)
				.commandId(CommandTestFactory.ID)
				.vorgangId(VorgangTestFactory.ID_STR)
				.collaborationVorgangId(COLLABORATION_VORGANG_ID)
				.createdBy(CommandTestFactory.CREATED_BY)
				.titel(TITEL)
				.beschreibung(BESCHREIBUNG)
				.zustaendigeStelle(ZUSTAENDIGE_STELLE)
				.collaborationLevel(COLLABORATION_LEVEL);
	}

	public static Map<String, Object> createAsMap() {
		return Map.of(
				CollaborationRequest.PROPERTY_ID, ID,
				CollaborationRequest.PROPERTY_COMMAND_ID, CommandTestFactory.ID,
				CollaborationRequest.PROPERTY_VORGANG_ID, VorgangTestFactory.ID_STR,
				CollaborationRequest.PROPERTY_COLLABORATION_VORGANG_ID, COLLABORATION_VORGANG_ID,
				CollaborationRequest.PROPERTY_COLLABORATION_LEVEL, String.valueOf(COLLABORATION_LEVEL),
				CollaborationRequest.PROPERTY_CREATED_BY, CommandTestFactory.CREATED_BY,
				CollaborationRequest.PROPERTY_TITEL, TITEL,
				CollaborationRequest.PROPERTY_BESCHREIBUNG, BESCHREIBUNG,
				CollaborationRequest.PROPERTY_ZUSTAENDIGE_STELLE, FACHSTELLE_MAP);
	}
}
