/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration;

import java.util.TimeZone;

import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.test.mock.mockito.MockBean;
import org.springframework.context.annotation.Bean;
import org.springframework.security.authentication.AuthenticationTrustResolver;
import org.springframework.security.authentication.AuthenticationTrustResolverImpl;

import de.ozgcloud.apilib.common.command.grpc.CommandMapper;
import de.ozgcloud.apilib.common.command.grpc.CommandMapperImpl;
import de.ozgcloud.apilib.file.OzgCloudFileService;
import de.ozgcloud.apilib.user.UserProfileMapper;
import de.ozgcloud.apilib.vorgang.grpc.OzgCloudVorgangMapper;
import de.ozgcloud.apilib.vorgang.grpc.OzgCloudVorgangQueryMapper;
import de.ozgcloud.apilib.vorgang.grpc.OzgCloudVorgangStubMapper;
import de.ozgcloud.collaboration.common.callcontext.CollaborationManagerCallContextProvider;
import de.ozgcloud.vorgang.vorgang.VorgangServiceGrpc;

@SpringBootApplication(scanBasePackages = { "de.ozgcloud" })
public class CollaborationTestApplication {

	@MockBean
	private VorgangServiceGrpc.VorgangServiceBlockingStub vorgangServiceStub;
	@MockBean
	private OzgCloudVorgangStubMapper vorgangStubMapper;
	@MockBean
	private OzgCloudVorgangMapper vorgangMapper;
	@MockBean
	private OzgCloudVorgangQueryMapper vorgangQueryMapper;
	@MockBean
	private CollaborationManagerCallContextProvider contextProvider;
	@MockBean
	private OzgCloudFileService ozgCloudFileService;
	@MockBean
	private UserProfileMapper userProfileMapper;

	public static void main(String[] args) {
		TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
		SpringApplication.run(CollaborationTestApplication.class, args);
	}

	@Bean
	AuthenticationTrustResolver trustResolver() {
		return new AuthenticationTrustResolverImpl();
	}

	@Bean
	CommandMapper commandMapper() {
		return new CommandMapperImpl();
	}

}
