/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration.common.freemarker;

import static org.assertj.core.api.Assertions.*;

import java.util.Collections;
import java.util.Map;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;

import de.ozgcloud.collaboration.CollaborationService;
import de.ozgcloud.common.errorhandling.TechnicalException;
import de.ozgcloud.common.test.ITCase;

@ITCase
class TemplateHandlerITCase {

	@Autowired
	private TemplateHandler handler;

	@DisplayName("Fill template")
	@Nested
	class TestFillTemplate {

		@Test
		void shouldReturnFilledTemplate() {
			var value = "http://test.url";
			var content = handler.fillTemplate(CollaborationService.COLLABORATION_NACHRICHT_TEMPLATE,
					Map.of(CollaborationService.KEY_VORGANG_LINK, value));

			assertThat(content)
					.contains("Guten Tag,")
					.contains("Sie haben eine Zuarbeitsanfrage erhalten. Bitte klicken Sie auf folgenden Link, um zum Vorgang zu gelangen:")
					.contains(value);
		}

		@Test
		void shouldThrowException() {
			var templateArguments = Collections.emptyMap();

			Assertions.assertThrows(TechnicalException.class,
					() -> handler.fillTemplate(CollaborationService.COLLABORATION_NACHRICHT_TEMPLATE, templateArguments));
		}
	}
}
