/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration.common.vorgang.attached_item;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import java.util.List;
import java.util.stream.Stream;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.collaboration.vorgang.VorgangTestFactory;

class VorgangAttachedItemServiceTest {

	@InjectMocks
	private VorgangAttachedItemService service;
	@Mock
	private VorgangAttachedItemRemoteService remoteService;

	@DisplayName("Get by id")
	@Nested
	class TestGetById {

		private final VorgangAttachedItem vorgangAttachedItem = VorgangAttachedItemTestFactory.create();

		@BeforeEach
		void mock() {
			when(remoteService.getById(any())).thenReturn(vorgangAttachedItem);
		}

		@Test
		void shouldCallRemoteService() {
			service.getById(VorgangAttachedItemTestFactory.ID);

			verify(remoteService).getById(VorgangAttachedItemTestFactory.ID);
		}

		@Test
		void shouldReturnItem() {
			var item = service.getById(VorgangAttachedItemTestFactory.ID);

			assertThat(item).usingRecursiveComparison().isEqualTo(vorgangAttachedItem);
		}
	}

	@DisplayName("Find by vorgangId")
	@Nested
	class TestFindByVorgangId {

		private final VorgangAttachedItem vorgangAttachedItem = VorgangAttachedItemTestFactory.create();

		@BeforeEach
		void mock() {
			when(remoteService.findByVorgangId(any(), any())).thenReturn(Stream.of(vorgangAttachedItem));
		}

		@Test
		void shouldCallRemoteService() {
			findByVorgangId();

			verify(remoteService).findByVorgangId(VorgangTestFactory.ID_STR, VorgangAttachedItemTestFactory.ITEM_NAME);
		}

		@Test
		void shouldReturnItems() {
			var items = findByVorgangId();

			assertThat(items).hasSize(1);
			assertThat(items.getFirst()).isEqualTo(vorgangAttachedItem);
		}

		private List<VorgangAttachedItem> findByVorgangId() {
			return service.findByVorgangId(VorgangTestFactory.ID_STR, VorgangAttachedItemTestFactory.ITEM_NAME).toList();
		}
	}
}
