/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration.fachstelle;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;

import de.ozgcloud.collaboration.fachstelle.Fachstelle.FachstelleType;

class FachstelleMapperTest {

	private final FachstelleMapper mapper = Mappers.getMapper(FachstelleMapper.class);

	@Nested
	class TestFromExterneFachstelle {

		@Test
		void shouldMapToFachstelle() {
			var expectedFachstelle = FachstelleTestFactory.createBuilder().type(FachstelleType.EXTERNE_FACHSTELLE).build();

			var fachstelle = mapper.fromExterneFachstelle(GrpcFachstelleTestFactory.create());

			assertThat(fachstelle).usingRecursiveComparison().isEqualTo(expectedFachstelle);
		}
	}

	@Nested
	class TestFromOrganisationEinheit {

		@Test
		void shouldMapToFachstelle() {
			var expectedFachstelle = FachstelleTestFactory.createBuilder().type(FachstelleType.ORGANISATION_EINHEIT).build();

			var fachstelle = mapper.fromOrganisationEinheit(GrpcOrganisationsEinheitTestFactory.create());

			assertThat(fachstelle).usingRecursiveComparison().isEqualTo(expectedFachstelle);
		}
	}

	@Nested
	class TestToMap {

		@Test
		void shouldMapToFachstelleMap() {
			var expectedMap = FachstelleTestFactory.createAsMap();

			var actualMap = mapper.toMap(FachstelleTestFactory.create());

			assertThat(actualMap).usingRecursiveComparison().isEqualTo(expectedMap);
		}
	}

	@Nested
	class TestFromMap {

		@Test
		void shouldMapToFachstelle() {
			var fachstelle = mapper.fromMap(FachstelleTestFactory.createAsMap());

			assertThat(fachstelle).isEqualTo(FachstelleTestFactory.create());
		}
	}
}
