/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration.fachstelle;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

class FachstelleServiceTest {

	@InjectMocks
	private FachstelleService service;

	@Mock
	private FachstelleRemoteService remoteService;

	@Nested
	class TestGetOrganisationEinheit {

		@Test
		void shouldGetOrganisationEinheit() {
			service.getOrganisationEinheit(FachstelleTestFactory.TECHNICAL_ID);

			verify(remoteService).getOrganisationEinheit(FachstelleTestFactory.TECHNICAL_ID);
		}

		@Test
		void shouldReturnFachstelle() {
			var expectedFachstelle = FachstelleTestFactory.create();
			when(remoteService.getOrganisationEinheit(any())).thenReturn(expectedFachstelle);

			var actualFachstelle = service.getOrganisationEinheit(FachstelleTestFactory.TECHNICAL_ID);

			assertThat(actualFachstelle).isSameAs(expectedFachstelle);
		}
	}

	@Nested
	class TestGetExterneFachstelle {

		@Test
		void shouldGetExterneFachstelle() {
			service.getExterneFachstelle(FachstelleTestFactory.TECHNICAL_ID);

			verify(remoteService).getExterneFachstelle(FachstelleTestFactory.TECHNICAL_ID);
		}

		@Test
		void shouldReturnFachstelle() {
			var expectedFachstelle = FachstelleTestFactory.create();
			when(remoteService.getExterneFachstelle(any())).thenReturn(expectedFachstelle);

			var actualFachstelle = service.getExterneFachstelle(FachstelleTestFactory.TECHNICAL_ID);

			assertThat(actualFachstelle).isSameAs(expectedFachstelle);
		}
	}
}
