/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration.vorgang;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import java.util.List;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.apilib.vorgang.OzgCloudAntragsteller;
import de.ozgcloud.apilib.vorgang.OzgCloudAntragstellerTestFactory;
import de.ozgcloud.apilib.vorgang.OzgCloudFormDataEntry;

class CollaborationAntragstellerMapperTest {

	@InjectMocks
	private CollaborationAntragstellerMapper mapper = Mappers.getMapper(CollaborationAntragstellerMapper.class);
	@Mock
	private CollaborationFormDataMapper formDataMapper = Mappers.getMapper(CollaborationFormDataMapper.class);

	@DisplayName("From ozgCloudAntragsteller")
	@Nested
	class TestFromOzgCloudAntragsteller {

		private List<FormDataEntry> otherData = List.of(FormDataEntryTestFactory.createFormField(), FormDataEntryTestFactory.createSubForm());
		private List<OzgCloudFormDataEntry> ozgCloudFormDataEntries = OzgCloudAntragstellerTestFactory.createOtherData();
		private OzgCloudAntragsteller ozgCloudAntragsteller = OzgCloudAntragstellerTestFactory.createBuilder().otherData(ozgCloudFormDataEntries)
				.build();

		@BeforeEach()
		void mock() {
			when(formDataMapper.fromOzgCloudEntries(any())).thenReturn(otherData);
		}

		@Test
		void shouldCallFormDataEntryMapper() {
			mapper.fromOzgCloudAntragsteller(ozgCloudAntragsteller);

			verify(formDataMapper).fromOzgCloudEntries(ozgCloudFormDataEntries);
		}

		@Test
		void shouldMap() {
			var mappedAntragsteller = mapper.fromOzgCloudAntragsteller(ozgCloudAntragsteller);

			assertThat(mappedAntragsteller).usingRecursiveComparison().isEqualTo(AntragstellerTestFactory.create());
		}
	}

	@DisplayName("To grpc")
	@Nested
	class TestToGrpc {

		@BeforeEach()
		void mock() {
			when(formDataMapper.toGrpcFormData(any())).thenReturn(GrpcFormDataTestFactory.create());
		}

		@Test
		void shouldCallFormDataEntryMapper() {
			mapper.toGrpc(AntragstellerTestFactory.create());

			verify(formDataMapper).toGrpcFormData(AntragstellerTestFactory.OTHER_DATA);
		}

		@Test
		void shouldMapToGrpc() {
			var mappedAntragsteller = mapper.toGrpc(AntragstellerTestFactory.create());

			assertThat(mappedAntragsteller).usingRecursiveComparison().ignoringFields("memoizedHashCode")
					.isEqualTo(GrpcAntragstellerTestFactory.create());
		}
	}

}