/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration.vorgang;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.springframework.test.util.ReflectionTestUtils;

import de.ozgcloud.apilib.vorgang.OzgCloudServiceKonto;
import de.ozgcloud.apilib.vorgang.OzgCloudServiceKontoTestFactory;
import de.ozgcloud.apilib.vorgang.OzgCloudTrustLevel;
import de.ozgcloud.apilib.vorgang.grpc.GrpcServiceKontoTestFactory;
import de.ozgcloud.vorgang.common.grpc.GrpcObjectMapper;

class CollaborationServiceKontoMapperTest {

	private final CollaborationServiceKontoMapper mapper = Mappers.getMapper(CollaborationServiceKontoMapper.class);

	private final GrpcObjectMapper grpcObjectMapper = Mappers.getMapper(GrpcObjectMapper.class);

	@BeforeEach
	void init() {
		ReflectionTestUtils.setField(mapper, "grpcObjectMapper", grpcObjectMapper);
	}

	@Nested
	class TestFromServiceKonto {

		private static final OzgCloudServiceKonto SERVICE_KONTO = OzgCloudServiceKontoTestFactory.createBuilder()
				.trustLevel(OzgCloudTrustLevel.from(ServiceKontoTestFactory.TRUST_LEVEL.getValue())).build();

		@Test
		void shouldMapServiceKonto() {
			var result = mapper.fromServiceKonto(SERVICE_KONTO);

			assertThat(result).usingRecursiveComparison().isEqualTo(ServiceKontoTestFactory.create());
		}
	}

	@Nested
	class TestToServiceKonto {

		private static final ServiceKonto SERVICE_KONTO = ServiceKontoTestFactory.create();

		@Test
		void shouldMapServiceKonto() {
			var grpcServiceKonto = GrpcServiceKontoTestFactory.createBuilder().setTrustLevel(ServiceKontoTestFactory.TRUST_LEVEL.getValue())
					.build();

			var result = mapper.toServiceKonto(SERVICE_KONTO);

			assertThat(result).usingRecursiveComparison().isEqualTo(grpcServiceKonto);
		}
	}
}