/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration.vorgang;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.apilib.vorgang.OzgCloudEingang;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgang;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangEingangTestFactory;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangTestFactory;

class CollaborationVorgangMapperTest {

	@InjectMocks
	private final CollaborationVorgangMapper mapper = Mappers.getMapper(CollaborationVorgangMapper.class);
	@Mock
	private CollaborationEingangMapper eingangMapper;
	@Mock
	private CollaborationServiceKontoMapper serviceKontoMapper;

	@DisplayName("From ozgCloudVorgang")
	@Nested
	class TestFromOzgCloudVorgang {

		private final OzgCloudEingang ozgCloudEingang = OzgCloudVorgangEingangTestFactory.create();
		private final OzgCloudVorgang ozgCloudVorgang = OzgCloudVorgangTestFactory.createBuilder()
				.id(VorgangTestFactory.ID)
				.clearEingangs().eingang(ozgCloudEingang)
				.build();

		@BeforeEach
		void mock() {
			when(eingangMapper.fromOzgCloudEingang(any())).thenReturn(EingangTestFactory.create());
			when(serviceKontoMapper.fromServiceKonto(any())).thenReturn(ServiceKontoTestFactory.create());
		}

		@Test
		void shouldCallEingangMapper() {
			mapper.fromOzgCloudVorgang(ozgCloudVorgang);

			verify(eingangMapper).fromOzgCloudEingang(ozgCloudEingang);
		}

		@Test
		void shouldCallServiceKontoMapper() {
			mapper.fromOzgCloudVorgang(ozgCloudVorgang);

			verify(serviceKontoMapper).fromServiceKonto(ozgCloudVorgang.getHeader().getServiceKonto());
		}

		@Test
		void shouldMap() {
			var mappedVorgang = mapper.fromOzgCloudVorgang(ozgCloudVorgang);

			assertThat(mappedVorgang).usingRecursiveComparison().ignoringFields("collaborationRequest")
					.isEqualTo(VorgangTestFactory.create());
		}
	}

	@DisplayName("To grpc")
	@Nested
	class TestToGrpc {

		@BeforeEach
		void mock() {
			when(eingangMapper.toGrpc(any())).thenReturn(GrpcEingangTestFactory.create());
		}

		@Test
		void shouldCallEingangMapper() {
			mapper.toGrpc(VorgangTestFactory.create());

			verify(eingangMapper).toGrpc(VorgangTestFactory.EINGANG);
		}

		@Test
		void shouldMap() {
			var vorgang = mapper.toGrpc(VorgangTestFactory.create());

			assertThat(vorgang).usingRecursiveComparison().isEqualTo(GrpcVorgangTestFactory.create());
		}
	}
}