/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration.vorgang;

import java.util.List;

import de.ozgcloud.collaboration.common.file.File;
import de.ozgcloud.collaboration.common.file.FileGroup;
import de.ozgcloud.collaboration.common.file.FileGroupTestFactory;
import de.ozgcloud.collaboration.common.file.FileTestFactory;

public class EingangTestFactory {

	public final static Antragsteller ANTRAGSTELLER = AntragstellerTestFactory.create();
	public final static FileGroup ATTACHMENT = FileGroupTestFactory.create();
	public final static File REPRESENTATION = FileTestFactory.create();

	public final static FormField FORM_FIELD = FormDataEntryTestFactory.createFormField();
	public final static SubForm SUB_FORM = FormDataEntryTestFactory.createSubForm();
	public final static List<FormDataEntry> FORM_DATA_ENTRIES = List.of(FORM_FIELD, SUB_FORM);

	public static Eingang create() {
		return createBuilder().build();
	}

	public static Eingang.EingangBuilder createBuilder() {
		return Eingang.builder()
				.antragsteller(ANTRAGSTELLER)
				.attachment(ATTACHMENT)
				.representation(REPRESENTATION)
				.formDataEntrys(FORM_DATA_ENTRIES);
	}
}