/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.collaboration.vorgang;

import de.ozgcloud.collaboration.GrpcFormData;
import de.ozgcloud.collaboration.GrpcFormField;
import de.ozgcloud.collaboration.GrpcSubForm;
import de.ozgcloud.collaboration.GrpcSubFormData;

public class GrpcFormDataTestFactory {

	public static final GrpcSubFormData SUB_FORM_FORM_FIELD = GrpcSubFormData.newBuilder().setField(
			GrpcFormField.newBuilder()
					.setName(FormDataEntryTestFactory.SUB_FORM_FIELD_NAME)
					.setValue(FormDataEntryTestFactory.SUB_FORM_FIELD_VALUE)
					.setLabel(FormDataEntryTestFactory.SUB_FORM_FIELD_LABEL).build())
			.build();

	public static final GrpcFormData create() {
		return createBuilder().build();
	}

	public static final GrpcFormData.Builder createBuilder() {
		return GrpcFormData.newBuilder()
				.addFormData(createSubFormDataForm())
				.addFormData(createSubFormDataField());
	}

	public static final GrpcSubFormData createSubFormDataForm() {
		return GrpcSubFormData.newBuilder().setForm(createSubForm()).build();
	}

	public static final GrpcSubForm createSubForm() {
		return createSubFormBuilder().build();
	}

	public static final GrpcSubForm.Builder createSubFormBuilder() {
		return GrpcSubForm.newBuilder()
				.setName(FormDataEntryTestFactory.SUB_FORM_NAME)
				.setLabel(FormDataEntryTestFactory.SUB_FORM_LABEL)
				.addFormData(SUB_FORM_FORM_FIELD);
	}

	public static final GrpcSubFormData createSubFormDataField() {
		return GrpcSubFormData.newBuilder().setField(createFormField()).build();
	}

	public static final GrpcFormField createFormField() {
		return createFormFieldBuilder().build();
	}

	public static final GrpcFormField.Builder createFormFieldBuilder() {
		return GrpcFormField.newBuilder()
				.setName(FormDataEntryTestFactory.FORM_FIELD_NAME)
				.setValue(FormDataEntryTestFactory.FORM_FIELD_VALUE)
				.setLabel(FormDataEntryTestFactory.FORM_FIELD_LABEL);
	}
}